import React from 'react';
import { MDCDialogFoundation } from '@material/dialog/foundation';
import { MDCDialogAdapter } from '@material/dialog/adapter';
import DialogContent, { DialogContentProps } from './DialogContent';
import DialogFooter, { DialogFooterProps } from './DialogFooter';
import DialogTitle, { DialogTitleProps } from './DialogTitle';
import DialogButton from './DialogButton';
import { FocusTrap } from 'focus-trap';
export declare type ChildTypes = DialogTitle<DialogTitleProps<{}>> | DialogContent<DialogContentProps<{}>> | DialogFooter<DialogFooterProps<{}>>;
export interface DialogProps<T, TitleProps extends {} = DialogTitleProps<HTMLHeadingElement>, ContentProps extends {} = DialogContentProps<HTMLDivElement>, FooterProps extends {} = DialogFooterProps<HTMLElement>> extends React.HTMLProps<T> {
    autoStackButtons?: boolean;
    children?: (React.ReactElement<TitleProps> | React.ReactElement<ContentProps> | React.ReactElement<FooterProps>)[] | React.ReactElement<FooterProps> | React.ReactElement<ContentProps> | React.ReactElement<TitleProps>;
    className?: string;
    escapeKeyAction?: string;
    id?: string;
    onClose?: (action: string) => void;
    onClosing?: (action: string) => void;
    onOpen?: () => void;
    onOpening?: () => void;
    open?: boolean;
    role?: 'alertdialog' | 'dialog';
    scrimClickAction?: string;
    tag?: string;
}
interface DialogState {
    classList: Set<string>;
}
declare class Dialog<T extends HTMLElement = HTMLElement> extends React.Component<DialogProps<T>, DialogState> {
    focusTrap?: FocusTrap;
    foundation: MDCDialogFoundation;
    dialogElement: React.RefObject<HTMLElement>;
    labelledBy?: string;
    describedBy?: string;
    static defaultProps: Partial<DialogProps<HTMLElement>>;
    state: DialogState;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: DialogProps<T>): void;
    readonly classes: string;
    readonly buttons: HTMLButtonElement[];
    readonly content: HTMLElement | null;
    readonly defaultButton: HTMLButtonElement | null;
    private open;
    private initializeFocusTrap;
    readonly adapter: MDCDialogAdapter;
    handleOpening: () => void;
    handleClosing: (action: string) => void;
    handleInteraction: (e: React.KeyboardEvent<HTMLElement> | React.MouseEvent<HTMLElement, MouseEvent>) => void;
    handleDocumentKeyDown: (e: KeyboardEvent) => void;
    handleLayout: () => void;
    render(): JSX.Element;
    renderContainer: (children?: ChildTypes[] | undefined) => React.ReactElement<HTMLDivElement, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)> | null) | (new (props: any) => React.Component<any, any, any>)> | undefined;
    renderChild: (child: ChildTypes, i: number) => ChildTypes;
    setId: (child: ChildTypes, componentId?: string | undefined) => string;
}
export default Dialog;
export { DialogTitle, DialogContent, DialogFooter, DialogButton };
